import { __assign } from './../../../external/tslib/tslib.es6.js';
import React from 'react';
import classnames from 'classnames';
import compose from 'lodash/fp/compose';
import curryN from 'lodash/fp/curryN';
import { parseMetadata } from '@highlight-ui/utils-commons';
import styles from './Pagination.module.scss.js';
import calcMaxPage from '../../utils/calcMaxPage.js';
import calcPage from '../../utils/calcPage.js';
import calcCenterPagePosition from '../../utils/calcCenterPagePosition.js';
import getPrevNumberList from '../../utils/getPrevNumberList.js';
import incrementList from '../../utils/incrementList.js';
import calcOffset from '../../utils/calcOffset.js';
import getPageFromEvent from '../../utils/getPageFromEvent.js';
import Nav from '../Nav/Nav.js';
import { Typography } from '../../../packages/ui/typography/dist/esm/index.js';
var Pagination = /*#__PURE__*/React.forwardRef(function (_a, ref) {
  var className = _a.className,
      metadata = _a.metadata,
      _b = _a.firstPageIconName,
      first = _b === void 0 ? 'angle-double-left' : _b,
      _c = _a.prevPageIconName,
      prev = _c === void 0 ? 'angle-left' : _c,
      _d = _a.nextPageIconName,
      next = _d === void 0 ? 'angle-right' : _d,
      _e = _a.lastPageIconName,
      last = _e === void 0 ? 'angle-double-right' : _e,
      limit = _a.limit,
      _f = _a.maxItems,
      maxItems = _f === void 0 ? 0 : _f,
      offset = _a.offset,
      onChange = _a.onChange,
      total = _a.total;
  var maxPage = calcMaxPage(limit, total);
  var page = calcPage(limit, offset);
  var centerIndex = calcCenterPagePosition(maxItems);
  var previousPages = getPrevNumberList([], page, centerIndex - 1);
  var displayList = incrementList(previousPages, maxItems, maxPage, page);
  var getOffsetOf = curryN(2, calcOffset)(limit);
  var onPaginate = compose([onChange, getOffsetOf, Number, getPageFromEvent]);
  return /*#__PURE__*/React.createElement("ul", __assign({
    className: classnames(styles.pagination, className),
    ref: ref
  }, parseMetadata(metadata)), page > 1 && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Nav, {
    page: 1,
    icon: first,
    onClick: onPaginate,
    className: styles.page,
    buttonClassName: styles.pageButton
  }), /*#__PURE__*/React.createElement(Nav, {
    page: page - 1,
    icon: prev,
    onClick: onPaginate,
    buttonClassName: styles.pageButton
  })), displayList.map(function (innerPage) {
    var _a;

    return /*#__PURE__*/React.createElement("li", {
      key: innerPage,
      className: styles.page
    }, /*#__PURE__*/React.createElement("a", __assign({}, parseMetadata({
      testId: "pagination-page-" + innerPage
    }), {
      role: "button",
      "data-page": innerPage,
      className: classnames(styles.pageButton, (_a = {}, _a[styles.active] = innerPage === page, _a)),
      onClick: onPaginate
    }), /*#__PURE__*/React.createElement(Typography, {
      variant: "button-1",
      component: "span"
    }, innerPage)));
  }), page < maxPage && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Nav, {
    page: page + 1,
    icon: next,
    onClick: onPaginate,
    buttonClassName: styles.pageButton
  }), /*#__PURE__*/React.createElement(Nav, {
    page: maxPage,
    icon: last,
    onClick: onPaginate,
    buttonClassName: styles.pageButton
  })));
});
export { Pagination as default };
//# sourceMappingURL=Pagination.js.map
